<?php
echo '<h1>INBOX25 Module Configuration</h1>';

// detect updates and save to config
if(isset($_POST['url'])) {

  // Sugar will attempt to change html entities (e.g. & => &amp;), but we don't
  // want that so decode, then validate the URL and its protocol
  $url = html_entity_decode($_POST['url']);
  $is_valid_url = filter_var($url, FILTER_VALIDATE_URL, FILTER_FLAG_SCHEME_REQUIRED);
  $is_valid_scheme = FALSE;
  if(substr($url, 0, 4) == 'http' || substr($url, 0, 5) == 'https') {
    $is_valid_scheme = TRUE;
  }

  if($is_valid_url && $is_valid_scheme) {
    require_once('modules/Configurator/Configurator.php');
    $configurator = new Configurator();
    $configurator->loadConfig();
    $configurator->config['inbox25']['url'] = $url;
    $configurator->config['inbox25']['height'] = $_POST['height'];
    $configurator->saveConfig();
    echo '<div style="color:red;margin:10px 0px;">Configuration Updated</div>';
  }
  else {
    echo '<div style="color:red;margin:10px 0px;font-weight:bold;">Invalid URL</div>';
    echo '<div style="color:red;margin:10px 0px;">Please correct the URL</div>';
  }

}

// load current values or defaults
global $sugar_config;
$url = isset($sugar_config['inbox25']['url']) ? $sugar_config['inbox25']['url'] : '';
$height = isset($sugar_config['inbox25']['height']) ? $sugar_config['inbox25']['height'] : '800';

// CSCF Tokens are required for SugarCRM versions 7.8 and higher, optional for
// 7.7x and unavailable in previous versions (including 6.5.26 CE and any
// SuiteCRM based system).

// always skip CSCF for SuiteCRM
$skip_cscf = !empty($GLOBALS['sugar_config']['suitecrm_version']);

// always skip for SugarCRM 6.5.x branch (i.e. we could be using Sugar CE)
if(!$skip_cscf) {
  $skip_cscf = (substr($GLOBALS['sugar_config']['sugar_version'], 0, 4) == '6.5.');
}

// if using SugarCRM 7.7 and CSCF is not enabled (i.e. not set or set FALSE)
// then we can skip it
if(
  !$skip_cscf
  && substr($GLOBALS['sugar_config']['sugar_version'], 0, 4) == '7.7.'
  && empty($GLOBALS['sugar_config']['csrf']['opt_in'])
) {
  $skip_cscf = TRUE;
}

if(!$skip_cscf) {
  $csrf = Sugarcrm\Sugarcrm\Security\Csrf\CsrfAuthenticator::getInstance();
  $csrf_token = sprintf(
    '<input type="hidden" name="%s" value="%s" />',
    $csrf::FORM_TOKEN_FIELD,
    $csrf->getFormToken()
  );
}
else {
  $csrf_token = '';
}

echo <<<EOFORM
<form name="Inbox25Integration" id="EditView" method="POST" action="index.php">
  <input type="hidden" name="module" value="Administration">
  <input type="hidden" name="action" value="Inbox25">
  {$csrf_token}

  <fieldset>
    <legend>INBOX25 Connection Info</legend>
    <label for='url'>URL</label><br />
    <input type='text' id='url' name='url' value='{$url}' /><br />
    <br />
    <label for='url'>Height (in px)</label><br />
    <input type='text' id='height' name='height' value='{$height}' /><br />
  </fieldset>

  <input type='submit' value='Save Configuration' />
</form>
EOFORM;

// add some basic info. about the current URL and integration status
require_once('modules/Iframeapp/Iframeapp.php');
$get_module_version = Iframeapp::get_module_version();
$get_url_ts = Iframeapp::get_url_ts();
$get_config_url = Iframeapp::get_config_url();
$get_config_height = Iframeapp::get_config_height();
$get_logic_hook_enabled = Iframeapp::get_logic_hook_enabled() ? 'TRUE' : 'FALSE';

if(!empty($get_config_url)) {
  echo <<<EOINFO
<style type='text/css'>
  table#inbox25_integration_info th, table#inbox25_integration_info td {
    border: 1px solid black;
    padding: .5em;
  }
</style>
<h2>Integration Information</h2>
<table id='inbox25_integration_info'>
  <thead>
    <tr>
      <th>Data Source</th>
      <th>Output</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td>Iframeapp::get_module_version()</td>
      <td><code>{$get_module_version}</code></td>
    </tr>
    <tr>
      <td>Iframeapp::get_url_ts()</td>
      <td><code>{$get_url_ts}</code></td>
    </tr>
    <tr>
      <td>Iframeapp::get_config_url()</td>
      <td><code>{$get_config_url}</code></td>
    </tr>
    <tr>
      <td>Iframeapp::get_config_height()</td>
      <td><code>{$get_config_height}</code></td>
    </tr>
    <tr>
      <td>Iframeapp::get_logic_hook_enabled()</td>
      <td><code>{$get_logic_hook_enabled}</code></td>
    </tr>
  </tbody>
</table>
EOINFO;

}
