<?php
require_once('modules/ACL/install_actions.php');
require_once('modules/ModuleBuilder/parsers/ParserFactory.php');
require_once('modules/Users/User.php');

function post_install() {

  // copy existing config. to new config. structure if we haven't already set
  // the connection info
  global $db, $sugar_config;
  if(empty($sugar_config['inbox25']) || empty($sugar_config['inbox25']['url'])) {
    $result = $db->query('select iframe_src, iframe_height from iframeapp where deleted=0 order by date_modified desc limit 1');
    while($row = $db->fetchByAssoc($result)) {
      $url = $row['iframe_src'];
      $height = $row['iframe_height'];
      require_once('modules/Configurator/Configurator.php');
      $configurator = new Configurator();
      $configurator->loadConfig();
      $configurator->config['inbox25']['url'] = $url;
      $configurator->config['inbox25']['height'] = $height;
      $configurator->saveConfig();
      echo "INBOX25 Config: updating config. backend with found iframe URL {$url} <br />" . PHP_EOL;
      echo "INBOX25 Config: updating config. backend with found iframe height {$height} <br />" . PHP_EOL;
    }
  }

  // Add the footerTpl information to the detail view metadata for all
  // supported modules
  // https://community.sugarcrm.com/thread/18554
  $footerTpl = 'modules/Iframeapp/OtherModuleTpls/DetailView.tpl';
  $modules_to_support = array(
    'Accounts',
    'Contacts',
    'Leads',
    'Opportunities',
    'Prospects',
  );
  foreach($modules_to_support as $module) {
    $view_array = ParserFactory::getParser('detailview', $module);
    // see if there is an existing value
    if(!empty($view_array->_viewdefs['templateMeta']['form']['footerTpl'])) {
      $existing_value = $view_array->_viewdefs['templateMeta']['form']['footerTpl'];
      if($existing_value != $footerTpl) {
        echo "<span style='color:red;font-weight:bold;'>INBOX25 Problem: {$module} module already has a footerTpl specified. This installer will not override it, which means the INBOX25 record-view integration will not function for this module until this is resolved.</span><br />" . PHP_EOL;
      }
    }
    else {
      $view_array->_viewdefs['templateMeta']['form']['footerTpl'] = $footerTpl;
      $view_array->handleSave(false);
    }
  }

  // run a full Quick Repair and Rebuild
  require_once('modules/Administration/QuickRepairAndRebuild.php');
  $repair = new RepairAndClear();
  $repair->repairAndClearAll(array('clearAll'), array('All Modules'), TRUE, FALSE);

  // prompt user to config. the INBOX25 connection info.
  global $sugar_config;
  $url = $sugar_config['site_url'] . '/index.php?module=Administration&action=Inbox25';
  $onclick = "window.open('{$url}','popup','width=600,height=600'); return false;";

  echo "<br />" . PHP_EOL;
  echo "<h2>Thanks for installing the INBOX25 SugarCRM Plugin</h2>" . PHP_EOL;
  echo "<p>Please configure your INBOX25 connection "
  . "<a href=\"{$url}\" onclick=\"{$onclick}\">on the admin. config. page</a>"
  . "</p>";

}
